# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import freeclimb
from freeclimb.models.application_list import ApplicationList  # noqa: E501
from freeclimb.models.application_result import ApplicationResult
from freeclimb.rest import ApiException


class TestApplicationList(unittest.TestCase):
    """ApplicationList unit test stubs"""

    def setUp(self):
        self.application1 = ApplicationResult('http://localhost:80/application1')
        self.application2 = ApplicationResult('http://localhost:80/application2')
        self.application_list = ApplicationList(next_page_uri='http://localhost:80/2', applications=[self.application1, self.application2])

    def tearDown(self):
        pass

    def testApplicationList(self):
        """Test ApplicationList"""
        # construct object with mandatory attributes with example values
        # model = freeclimb.models.application_list.ApplicationList()  # noqa: E501
        self.assertTrue(isinstance(self.application_list, ApplicationList))


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import freeclimb
from freeclimb.models.application_list_all_of import ApplicationListAllOf  # noqa: E501
from freeclimb.models.application_result import ApplicationResult
from freeclimb.rest import ApiException


class TestApplicationListAllOf(unittest.TestCase):
    """ApplicationListAllOf unit test stubs"""

    def setUp(self):
        self.application1 = ApplicationResult(uri='http://localhost:80/application1')
        self.application2 = ApplicationResult(uri='http://localhost:80/application2')
        self.application_list_all_of = ApplicationListAllOf([self.application1, self.application2])

    def tearDown(self):
        pass

    def testApplicationListAllOf(self):
        """Test ApplicationListAllOf"""
        # construct object with mandatory attributes with example values
        # model = freeclimb.models.application_list_all_of.ApplicationListAllOf()  # noqa: E501
        self.assertTrue(isinstance(self.application_list_all_of, ApplicationListAllOf))


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class MessageRequestAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_from': 'str',
        'to': 'str',
        'text': 'str',
        'notification_url': 'str',
        'request_id': 'str',
        'account_id': 'str'
    }

    attribute_map = {
        '_from': 'from',
        'to': 'to',
        'text': 'text',
        'notification_url': 'notificationUrl',
        'request_id': 'requestId',
        'account_id': 'accountId'
    }

    def __init__(self, _from=None, to=None, text=None, notification_url=None, request_id=None, account_id=None, local_vars_configuration=None):  # noqa: E501
        """MessageRequestAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.__from = None
        self._to = None
        self._text = None
        self._notification_url = None
        self._request_id = None
        self._account_id = None
        self.discriminator = None

        self._from = _from
        self.to = to
        self.text = text
        if notification_url is not None:
            self.notification_url = notification_url
        if request_id is not None:
            self.request_id = request_id
        if account_id is not None:
            self.account_id = account_id

    @property
    def _from(self):
        """Gets the _from of this MessageRequestAllOf.  # noqa: E501

        Phone number to use as the sender. This must be an incoming phone number that you have purchased from FreeClimb.  # noqa: E501

        :return: The _from of this MessageRequestAllOf.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this MessageRequestAllOf.

        Phone number to use as the sender. This must be an incoming phone number that you have purchased from FreeClimb.  # noqa: E501

        :param _from: The _from of this MessageRequestAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and _from is None:  # noqa: E501
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this MessageRequestAllOf.  # noqa: E501

        Phone number to receive the message. Must be within FreeClimb's service area.  # noqa: E501

        :return: The to of this MessageRequestAllOf.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this MessageRequestAllOf.

        Phone number to receive the message. Must be within FreeClimb's service area.  # noqa: E501

        :param to: The to of this MessageRequestAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def text(self):
        """Gets the text of this MessageRequestAllOf.  # noqa: E501

        Text contained in the message (maximum 160 characters).   **Note:** For text, only ASCII characters are supported.  # noqa: E501

        :return: The text of this MessageRequestAllOf.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this MessageRequestAllOf.

        Text contained in the message (maximum 160 characters).   **Note:** For text, only ASCII characters are supported.  # noqa: E501

        :param text: The text of this MessageRequestAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def notification_url(self):
        """Gets the notification_url of this MessageRequestAllOf.  # noqa: E501

        When the Message changes status, this URL is invoked using HTTP POST with the messageStatus parameters.  **Note:** This is a notification only; any PerCL returned is ignored.  # noqa: E501

        :return: The notification_url of this MessageRequestAllOf.  # noqa: E501
        :rtype: str
        """
        return self._notification_url

    @notification_url.setter
    def notification_url(self, notification_url):
        """Sets the notification_url of this MessageRequestAllOf.

        When the Message changes status, this URL is invoked using HTTP POST with the messageStatus parameters.  **Note:** This is a notification only; any PerCL returned is ignored.  # noqa: E501

        :param notification_url: The notification_url of this MessageRequestAllOf.  # noqa: E501
        :type: str
        """

        self._notification_url = notification_url

    @property
    def request_id(self):
        """Gets the request_id of this MessageRequestAllOf.  # noqa: E501

        RequestId for this request, starting with prefix *RQ* followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g., X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :return: The request_id of this MessageRequestAllOf.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this MessageRequestAllOf.

        RequestId for this request, starting with prefix *RQ* followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g., X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :param request_id: The request_id of this MessageRequestAllOf.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def account_id(self):
        """Gets the account_id of this MessageRequestAllOf.  # noqa: E501

        String that uniquely identifies this account resource.  # noqa: E501

        :return: The account_id of this MessageRequestAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this MessageRequestAllOf.

        String that uniquely identifies this account resource.  # noqa: E501

        :param account_id: The account_id of this MessageRequestAllOf.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageRequestAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MessageRequestAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import freeclimb
from freeclimb.models.call_result import CallResult  # noqa: E501
from freeclimb.rest import ApiException


class TestCallResult(unittest.TestCase):
    """CallResult unit test stubs"""

    def setUp(self):
        self.call_result = CallResult()

    def tearDown(self):
        pass

    def testCallResult(self):
        """Test CallResult"""
        # construct object with mandatory attributes with example values
        # model = freeclimb.models.call_result.CallResult()  # noqa: E501
        self.assertTrue(isinstance(self.call_result, CallResult))


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import freeclimb
from freeclimb.models.queue_list_all_of import QueueListAllOf  # noqa: E501
from freeclimb.rest import ApiException


class TestQueueListAllOf(unittest.TestCase):
    """QueueListAllOf unit test stubs"""

    def setUp(self):
        self.queue_list_all_of = QueueListAllOf()

    def tearDown(self):
        pass

    def testQueueListAllOf(self):
        """Test QueueListAllOf"""
        # construct object with mandatory attributes with example values
        # model = freeclimb.models.queue_list_all_of.QueueListAllOf()  # noqa: E501
        self.assertTrue(isinstance(self.queue_list_all_of, QueueListAllOf))


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class CreateConferenceRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alias': 'str',
        'play_beep': 'str',
        'record': 'bool',
        'wait_url': 'str',
        'status_callback_url': 'str',
        'request_id': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'play_beep': 'playBeep',
        'record': 'record',
        'wait_url': 'waitUrl',
        'status_callback_url': 'statusCallbackUrl',
        'request_id': 'requestId'
    }

    def __init__(self, alias=None, play_beep='always', record=None, wait_url=None, status_callback_url=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """CreateConferenceRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alias = None
        self._play_beep = None
        self._record = None
        self._wait_url = None
        self._status_callback_url = None
        self._request_id = None
        self.discriminator = None

        if alias is not None:
            self.alias = alias
        if play_beep is not None:
            self.play_beep = play_beep
        if record is not None:
            self.record = record
        if wait_url is not None:
            self.wait_url = wait_url
        if status_callback_url is not None:
            self.status_callback_url = status_callback_url
        if request_id is not None:
            self.request_id = request_id

    @property
    def alias(self):
        """Gets the alias of this CreateConferenceRequest.  # noqa: E501

        A description for this Conference. Maximum 64 characters.  # noqa: E501

        :return: The alias of this CreateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this CreateConferenceRequest.

        A description for this Conference. Maximum 64 characters.  # noqa: E501

        :param alias: The alias of this CreateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def play_beep(self):
        """Gets the play_beep of this CreateConferenceRequest.  # noqa: E501

        Controls when a beep is played. Valid values: `always`, `never`, `entryOnly`, `exitOnly`.  # noqa: E501

        :return: The play_beep of this CreateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._play_beep

    @play_beep.setter
    def play_beep(self, play_beep):
        """Sets the play_beep of this CreateConferenceRequest.

        Controls when a beep is played. Valid values: `always`, `never`, `entryOnly`, `exitOnly`.  # noqa: E501

        :param play_beep: The play_beep of this CreateConferenceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["always", "never", "entryOnly", "exitOnly"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and play_beep not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `play_beep` ({0}), must be one of {1}"  # noqa: E501
                .format(play_beep, allowed_values)
            )

        self._play_beep = play_beep

    @property
    def record(self):
        """Gets the record of this CreateConferenceRequest.  # noqa: E501

        Setting to `true` records the entire Conference.  # noqa: E501

        :return: The record of this CreateConferenceRequest.  # noqa: E501
        :rtype: bool
        """
        return self._record

    @record.setter
    def record(self, record):
        """Sets the record of this CreateConferenceRequest.

        Setting to `true` records the entire Conference.  # noqa: E501

        :param record: The record of this CreateConferenceRequest.  # noqa: E501
        :type: bool
        """

        self._record = record

    @property
    def wait_url(self):
        """Gets the wait_url of this CreateConferenceRequest.  # noqa: E501

        If specified, a URL for the audio file that provides custom hold music for the Conference when it is in the populated state. Otherwise, FreeClimb uses a system default audio file. This is always fetched using HTTP GET and is fetched just once &mdash; when the Conference is created.  # noqa: E501

        :return: The wait_url of this CreateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._wait_url

    @wait_url.setter
    def wait_url(self, wait_url):
        """Sets the wait_url of this CreateConferenceRequest.

        If specified, a URL for the audio file that provides custom hold music for the Conference when it is in the populated state. Otherwise, FreeClimb uses a system default audio file. This is always fetched using HTTP GET and is fetched just once &mdash; when the Conference is created.  # noqa: E501

        :param wait_url: The wait_url of this CreateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._wait_url = wait_url

    @property
    def status_callback_url(self):
        """Gets the status_callback_url of this CreateConferenceRequest.  # noqa: E501

        This URL is invoked when the status of the Conference changes. For more information, see **statusCallbackUrl** (below).  # noqa: E501

        :return: The status_callback_url of this CreateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._status_callback_url

    @status_callback_url.setter
    def status_callback_url(self, status_callback_url):
        """Sets the status_callback_url of this CreateConferenceRequest.

        This URL is invoked when the status of the Conference changes. For more information, see **statusCallbackUrl** (below).  # noqa: E501

        :param status_callback_url: The status_callback_url of this CreateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._status_callback_url = status_callback_url

    @property
    def request_id(self):
        """Gets the request_id of this CreateConferenceRequest.  # noqa: E501

        The requestId for this request starting with prefix \"RQ\" followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request will include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g., X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :return: The request_id of this CreateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this CreateConferenceRequest.

        The requestId for this request starting with prefix \"RQ\" followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request will include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g., X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :param request_id: The request_id of this CreateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConferenceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateConferenceRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class UpdateConferenceRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alias': 'str',
        'play_beep': 'str',
        'status': 'str',
        'request_id': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'play_beep': 'playBeep',
        'status': 'status',
        'request_id': 'requestId'
    }

    def __init__(self, alias=None, play_beep='always', status=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """UpdateConferenceRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alias = None
        self._play_beep = None
        self._status = None
        self._request_id = None
        self.discriminator = None

        if alias is not None:
            self.alias = alias
        if play_beep is not None:
            self.play_beep = play_beep
        if status is not None:
            self.status = status
        if request_id is not None:
            self.request_id = request_id

    @property
    def alias(self):
        """Gets the alias of this UpdateConferenceRequest.  # noqa: E501

        Description for this conference. Maximum 64 characters.  # noqa: E501

        :return: The alias of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this UpdateConferenceRequest.

        Description for this conference. Maximum 64 characters.  # noqa: E501

        :param alias: The alias of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def play_beep(self):
        """Gets the play_beep of this UpdateConferenceRequest.  # noqa: E501

        Controls when a beep is played. Valid values: `always`, `never`, `entryOnly`, `exitOnly`.  # noqa: E501

        :return: The play_beep of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._play_beep

    @play_beep.setter
    def play_beep(self, play_beep):
        """Sets the play_beep of this UpdateConferenceRequest.

        Controls when a beep is played. Valid values: `always`, `never`, `entryOnly`, `exitOnly`.  # noqa: E501

        :param play_beep: The play_beep of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._play_beep = play_beep

    @property
    def status(self):
        """Gets the status of this UpdateConferenceRequest.  # noqa: E501

        New status of the conference. Valid values: `empty` or `terminated`. For more information, see **Status Parameter** below.**  # noqa: E501

        :return: The status of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateConferenceRequest.

        New status of the conference. Valid values: `empty` or `terminated`. For more information, see **Status Parameter** below.**  # noqa: E501

        :param status: The status of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["empty", "terminated"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def request_id(self):
        """Gets the request_id of this UpdateConferenceRequest.  # noqa: E501

        ID for this request starting with prefix *RQ* followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request will include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g. X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :return: The request_id of this UpdateConferenceRequest.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this UpdateConferenceRequest.

        ID for this request starting with prefix *RQ* followed by 40 hexadecimal characters. FreeClimb logs generated while processing this request will include this requestId. If it is not provided, FreeClimb will generate a requestId and return it as a header in the response (e.g. X-Pulse-Request-Id: <requestId>).  # noqa: E501

        :param request_id: The request_id of this UpdateConferenceRequest.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateConferenceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateConferenceRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])
